OperationalState

Enum OperationalState 

#[repr(u8)]
pub enum OperationalState { Stopped = 0, Running = 1, Paused = 2, Error = 3, Seekingcharger = 64, Charging = 65, Docked = 66, Emptyingdustbin = 67, Cleaningmop = 68, Fillingwatertank = 69, Updatingmaps = 70, }

Variants



Stopped = 0

The device is stopped



Running = 1

The device is operating



Paused = 2

The device is paused during an operation



Error = 3

The device is in an error state



Seekingcharger = 64

The device is en route to the charging dock



Charging = 65

The device is charging



Docked = 66

The device is on the dock, not charging



Emptyingdustbin = 67

The device is automatically emptying its own dust bin, such as to a dock



Cleaningmop = 68

The device is automatically cleaning its own mopping device, such as on a dock



Fillingwatertank = 69

The device is automatically filling its own clean water tank for use when mopping, such as from a dock



Updatingmaps = 70

The device is processing acquired data to update its maps

Implementations

Source

impl OperationalState

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value