#[repr(u8)]pub enum ErrorState {
Show 19 variants
Noerror = 0,
Unabletostartorresume = 1,
Unabletocompleteoperation = 2,
Commandinvalidinstate = 3,
Failedtofindchargingdock = 64,
Stuck = 65,
Dustbinmissing = 66,
Dustbinfull = 67,
Watertankempty = 68,
Watertankmissing = 69,
Watertanklidopen = 70,
Mopcleaningpadmissing = 71,
Lowbattery = 72,
Cannotreachtargetarea = 73,
Dirtywatertankfull = 74,
Dirtywatertankmissing = 75,
Wheelsjammed = 76,
Brushjammed = 77,
Navigationsensorobscured = 78,
}Variants
Noerror = 0
The device is not in an error state
Unabletostartorresume = 1
The device is unable to start or resume operation
Unabletocompleteoperation = 2
The device was unable to complete the current operation
Commandinvalidinstate = 3
The device cannot process the command in its current state
Failedtofindchargingdock = 64
The device has failed to find or reach the charging dock
Stuck = 65
The device is stuck and requires manual intervention
Dustbinmissing = 66
The device has detected that its dust bin is missing
Dustbinfull = 67
The device has detected that its dust bin is full
Watertankempty = 68
The device has detected that its clean water tank is empty
Watertankmissing = 69
The device has detected that its clean water tank is missing
Watertanklidopen = 70
The device has detected that its water tank lid is open
Mopcleaningpadmissing = 71
The device has detected that its cleaning pad is missing
Lowbattery = 72
The device is unable to start or to continue operating due to a low battery
Cannotreachtargetarea = 73
The device is unable to move to an area where it was asked to operate, such as by setting the ServiceArea cluster’s SelectedAreas attribute, due to an obstruction. For example, the obstruction might be a closed door or objects blocking the mapped path.
Dirtywatertankfull = 74
The device has detected that its dirty water tank is full
Dirtywatertankmissing = 75
The device has detected that its dirty water tank is missing
Wheelsjammed = 76
The device has detected that one or more wheels are jammed by an object
Brushjammed = 77
The device has detected that its brush is jammed by an object
The device has detected that one of its sensors, such as LiDAR, infrared, or camera is obscured and needs to be cleaned
Implementations